import { __decorate } from "tslib";
import { bodyFont } from '@microsoft/fast-components';
import { customElement, FASTElement, observable, attr, DOM } from '@microsoft/fast-element';
import { defaultBodyFont, EventName } from '../../types';
import { applyStyleChanges } from '../../utils/utils';
import { JSON_SCHEMA, uiSchema } from './json_schema';
import { PreviewFormStyles as styles } from './preview-form.styles';
import { PreviewFormTemplate as template } from './preview-form.template';
let PreviewForm = class PreviewForm extends FASTElement {
    constructor() {
        super(...arguments);
        this.jsonSchema = JSON_SCHEMA;
        this.uischema = uiSchema;
        this.prefix = 'zero';
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (e) => {
            this.handleStyleChanges(e);
        });
        document.body.addEventListener(EventName.DS_CHANGED, (e) => {
            this.handleDSChanges(e);
        });
        DOM.queueUpdate(() => {
            bodyFont.withDefault(defaultBodyFont);
        });
    }
    handleStyleChanges(e) {
        const detail = e.detail;
        if (detail) {
            DOM.queueUpdate(() => {
                applyStyleChanges(detail, this.provider);
            });
        }
    }
    handleDSChanges(event) {
        this.prefix = event.detail.prefix;
        this.uischema.dsPrefix = event.detail.prefix;
    }
};
__decorate([
    observable
], PreviewForm.prototype, "jsonSchema", void 0);
__decorate([
    observable
], PreviewForm.prototype, "uischema", void 0);
__decorate([
    attr
], PreviewForm.prototype, "prefix", void 0);
__decorate([
    observable
], PreviewForm.prototype, "provider", void 0);
PreviewForm = __decorate([
    customElement({
        name: 'preview-form',
        template,
        styles,
    })
], PreviewForm);
export { PreviewForm };
